@@ -8,8 +8,9 @@ module Twitter
     # @return [Array<String>]
     attr_reader :non_username_paths
     # @return [Integer]
-    attr_reader :characters_reserved_per_media, :max_media_per_upload,
-                :photo_size_limit, :short_url_length, :short_url_length_https
+    attr_reader :characters_reserved_per_media, :dm_text_character_limit,
+                :max_media_per_upload, :photo_size_limit, :short_url_length,
+                :short_url_length_https
     alias short_uri_length short_url_length
     alias short_uri_length_https short_url_length_https
 
