@@ -3,7 +3,10 @@ require 'twitter/entity'
 module Twitter
   class Entity
     class UserMention < Twitter::Entity
-      attr_reader :id, :name, :screen_name
+      # @return [Integer]
+      attr_reader :id
+      # @return [String]
+      attr_reader :name, :screen_name
     end
   end
 end
