@@ -8,6 +8,10 @@ module Twitter
 
       # @return [Array<Integer>]
       attr_reader :indices
+
+      # @return [String]
+      attr_reader :type
+
       display_uri_attr_reader
       uri_attr_reader :expanded_uri, :media_uri, :media_uri_https, :uri
 
