@@ -9,6 +9,10 @@ module Twitter
 
       # @return [Array<Integer>]
       attr_reader :indices
+
+      # @return [String]
+      attr_reader :type
+
       display_uri_attr_reader
       uri_attr_reader :expanded_uri, :media_uri, :media_uri_https, :uri
 
@@ -18,7 +22,6 @@ module Twitter
       def sizes
         @attrs.fetch(:sizes, []).each_with_object({}) do |(key, value), object|
           object[key] = Size.new(value)
-          object
         end
       end
       memoize :sizes
