@@ -1,7 +1,7 @@
 require 'naught'
 
 module Twitter
-  NullObject = Naught.build do |config|
+  NullObject = Naught.build do |config| # rubocop:disable Metrics/BlockLength
     include Comparable
 
     config.black_hole
@@ -18,12 +18,14 @@ module Twitter
     end
 
     def instance_of?(klass)
-      raise(TypeError.new('class or module required')) unless klass.is_a?(Class)
+      raise(TypeError, 'class or module required') unless klass.is_a?(Class)
+
       self.class == klass
     end
 
     def kind_of?(mod)
-      raise(TypeError.new('class or module required')) unless mod.is_a?(Module)
+      raise(TypeError, 'class or module required') unless mod.is_a?(Module)
+
       self.class.ancestors.include?(mod)
     end
 
@@ -48,5 +50,17 @@ module Twitter
     def to_json(*args)
       nil.to_json(*args)
     end
+
+    def presence
+      nil
+    end
+
+    def blank?
+      true
+    end
+
+    def present?
+      false
+    end
   end
 end
