@@ -7,21 +7,21 @@ module Twitter
     # @return [Integer]
     def limit
       limit = @attrs['x-rate-limit-limit']
-      limit.to_i if limit
+      limit&.to_i
     end
     memoize :limit
 
     # @return [Integer]
     def remaining
       remaining = @attrs['x-rate-limit-remaining']
-      remaining.to_i if remaining
+      remaining&.to_i
     end
     memoize :remaining
 
     # @return [Time]
     def reset_at
       reset = @attrs['x-rate-limit-reset']
-      Time.at(reset.to_i) if reset
+      Time.at(reset.to_i).utc if reset
     end
     memoize :reset_at
 
