@@ -2,6 +2,7 @@ require 'twitter/arguments'
 require 'twitter/error'
 require 'twitter/oembed'
 require 'twitter/rest/request'
+require 'twitter/rest/upload_utils'
 require 'twitter/rest/utils'
 require 'twitter/tweet'
 require 'twitter/utils'
@@ -9,6 +10,7 @@ require 'twitter/utils'
 module Twitter
   module REST
     module Tweets
+      include Twitter::REST::UploadUtils
       include Twitter::REST::Utils
       include Twitter::Utils
       MAX_TWEETS_PER_REQUEST = 100
@@ -323,37 +325,6 @@ module Twitter
 
     private
 
-      # Uploads images and videos. Videos require multiple requests and uploads in chunks of 5 Megabytes.
-      # The only supported video format is mp4.
-      #
-      # @see https://dev.twitter.com/rest/public/uploading-media
-      def upload(media) # rubocop:disable MethodLength, AbcSize
-        if File.basename(media) !~ /\.mp4$/
-          Twitter::REST::Request.new(self, :multipart_post, 'https://upload.twitter.com/1.1/media/upload.json', key: :media, file: media).perform
-        else
-          init = Twitter::REST::Request.new(self, :post, 'https://upload.twitter.com/1.1/media/upload.json',
-                                            command: 'INIT',
-                                            media_type: 'video/mp4',
-                                            total_bytes: media.size).perform
-
-          until media.eof?
-            chunk = media.read(5_000_000)
-            seg ||= -1
-            Twitter::REST::Request.new(self, :multipart_post, 'https://upload.twitter.com/1.1/media/upload.json',
-                                       command: 'APPEND',
-                                       media_id: init[:media_id],
-                                       segment_index: seg += 1,
-                                       key: :media,
-                                       file: StringIO.new(chunk)).perform
-          end
-
-          media.close
-
-          Twitter::REST::Request.new(self, :post, 'https://upload.twitter.com/1.1/media/upload.json',
-                                     command: 'FINALIZE', media_id: init[:media_id]).perform
-        end
-      end
-
       def array_wrap(object)
         if object.respond_to?(:to_ary)
           object.to_ary || [object]
