@@ -30,11 +30,13 @@ module Twitter
       # @option options [Integer] :end_sleep_time The hour that sleep time should end if it is enabled. The value for this parameter should be provided in {http://en.wikipedia.org/wiki/ISO_8601 ISO8601} format (i.e. 00-23). The time is considered to be in the same timezone as the user's time_zone setting.
       # @option options [String] :time_zone The timezone dates and times should be displayed in for the user. The timezone must be one of the {http://api.rubyonrails.org/classes/ActiveSupport/TimeZone.html Rails TimeZone} names.
       # @option options [String] :lang The language which Twitter should render in for this user. The language must be specified by the appropriate two letter ISO 639-1 representation. Currently supported languages are provided by {https://dev.twitter.com/rest/reference/get/help/languages GET help/languages}.
+      # @option options [String] :allow_contributor_request Whether to allow others to include user as contributor. Possible values include 'all' (anyone can include user), 'following' (only followers can include user) or 'none'. Also note that changes to this field require the request also include a current_password value with the user's password to successfully modify this field.
+      # @option options [String] :current_password The user's password. This is only required when modifying the allow_contributor_request field.
       def settings(options = {})
         request_method = options.size.zero? ? :get : :post
         response = perform_request(request_method.to_sym, '/1.1/account/settings.json', options)
         # https://dev.twitter.com/issues/59
-        response.update(trend_location: response.fetch(:trend_location, []).first)
+        response[:trend_location] = response.fetch(:trend_location, []).first
         Twitter::Settings.new(response)
       end
 
@@ -50,7 +52,6 @@ module Twitter
       def verify_credentials(options = {})
         perform_get_with_object('/1.1/account/verify_credentials.json', options, Twitter::User)
       end
-      alias current_user verify_credentials
 
       # Sets which device Twitter delivers updates to for the authenticating user
       #
@@ -78,6 +79,7 @@ module Twitter
       # @option options [String] :url URL associated with the profile. Will be prepended with "http://" if not present. Maximum of 100 characters.
       # @option options [String] :location The city or country describing where the user of the account is located. The contents are not normalized or geocoded in any way. Maximum of 30 characters.
       # @option options [String] :description A description of the user owning the account. Maximum of 160 characters.
+      # @option options [String] :profile_link_color A hex value of the color scheme used for links on user's profile page. Must be a valid hexadecimal value, and may be either three or six characters
       def update_profile(options = {})
         perform_post_with_object('/1.1/account/update_profile.json', options, Twitter::User)
       end
@@ -93,24 +95,7 @@ module Twitter
       # @param options [Hash] A customizable set of options.
       # @option options [Boolean] :tile Whether or not to tile the background image. If set to true the background image will be displayed tiled. The image will not be tiled otherwise.
       def update_profile_background_image(image, options = {})
-        perform_post_with_object('/1.1/account/update_profile_background_image.json', options.merge(image: image), Twitter::User)
-      end
-
-      # Sets one or more hex values that control the color scheme of the authenticating user's profile
-      #
-      # @see https://dev.twitter.com/rest/reference/post/account/update_profile_colors
-      # @rate_limited No
-      # @authentication Requires user context
-      # @raise [Twitter::Error::Unauthorized] Error raised when supplied user credentials are not valid.
-      # @return [Twitter::User] The authenticated user.
-      # @param options [Hash] A customizable set of options.
-      # @option options [String] :profile_background_color Profile background color.
-      # @option options [String] :profile_text_color Profile text color.
-      # @option options [String] :profile_link_color Profile link color.
-      # @option options [String] :profile_sidebar_fill_color Profile sidebar's background color.
-      # @option options [String] :profile_sidebar_border_color Profile sidebar's border color.
-      def update_profile_colors(options = {})
-        perform_post_with_object('/1.1/account/update_profile_colors.json', options, Twitter::User)
+        post_profile_image('/1.1/account/update_profile_background_image.json', image, options)
       end
 
       # Updates the authenticating user's profile image
@@ -125,7 +110,7 @@ module Twitter
       # @param image [File] The avatar image for the profile, base64-encoded. Must be a valid GIF, JPG, or PNG image of less than 700 kilobytes in size. Images with width larger than 500 pixels will be scaled down. Animated GIFs will be converted to a static GIF of the first frame, removing the animation.
       # @param options [Hash] A customizable set of options.
       def update_profile_image(image, options = {})
-        perform_post_with_object('/1.1/account/update_profile_image.json', options.merge(image: image), Twitter::User)
+        post_profile_image('/1.1/account/update_profile_image.json', image, options)
       end
 
       # Returns an array of user objects that the authenticating user is blocking
@@ -140,7 +125,6 @@ module Twitter
       def blocked(options = {})
         perform_get_with_cursor('/1.1/blocks/list.json', options, :users, Twitter::User)
       end
-      deprecate_alias :blocking, :blocked
 
       # Returns an array of numeric user IDs the authenticating user is blocking
       #
@@ -167,17 +151,12 @@ module Twitter
       # @param user [Integer, String, URI, Twitter::User] A Twitter user ID, screen name, URI, or object.
       # @param options [Hash] A customizable set of options.
       def block?(user, options = {})
-        user_id = begin
+        user_id =
           case user
-          when Integer
-            user
-          when String, URI, Addressable::URI
-            user(user).id
-          when Twitter::User
-            user.id
+          when Integer                       then user
+          when String, URI, Addressable::URI then user(user).id
+          when Twitter::User                 then user.id
           end
-        end
-
         blocked_ids(options).collect(&:to_i).include?(user_id)
       end
 
@@ -229,7 +208,7 @@ module Twitter
       def users(*args)
         arguments = Twitter::Arguments.new(args)
         flat_pmap(arguments.each_slice(MAX_USERS_PER_REQUEST)) do |users|
-          perform_post_with_objects('/1.1/users/lookup.json', merge_users(arguments.options, users), Twitter::User)
+          perform_get_with_objects('/1.1/users/lookup.json', merge_users(arguments.options, users), Twitter::User)
         end
       end
 
@@ -267,6 +246,7 @@ module Twitter
       # @return [Boolean] true if the user exists, otherwise false.
       # @param user [Integer, String, Twitter::User] A Twitter user ID, screen name, URI, or object.
       def user?(user, options = {})
+        options = options.dup
         merge_user!(options, user)
         perform_get('/1.1/users/show.json', options)
         true
@@ -286,6 +266,7 @@ module Twitter
       # @option options [Integer] :count The number of people to retrieve. Maxiumum of 20 allowed per page.
       # @option options [Integer] :page Specifies the page of results to retrieve.
       def user_search(query, options = {})
+        options = options.dup
         perform_get_with_objects('/1.1/users/search.json', options.merge(q: query), Twitter::User)
       end
 
@@ -337,7 +318,6 @@ module Twitter
         perform_post('/1.1/account/remove_profile_banner.json', options)
         true
       end
-      deprecate_alias :profile_banner_remove, :remove_profile_banner
 
       # Updates the authenticating user's profile banner image
       #
@@ -422,7 +402,6 @@ module Twitter
       def muted(options = {})
         perform_get_with_cursor('/1.1/mutes/users/list.json', options, :users, Twitter::User)
       end
-      deprecate_alias :muting, :muted
 
       # Returns an array of numeric user IDs the authenticating user is muting
       #
@@ -438,6 +417,13 @@ module Twitter
         merge_user!(arguments.options, arguments.pop)
         perform_get_with_cursor('/1.1/mutes/users/ids.json', arguments.options, :ids)
       end
+
+    private
+
+      def post_profile_image(path, image, options)
+        response = Twitter::REST::Request.new(self, :multipart_post, path, options.merge(key: :image, file: image)).perform
+        Twitter::User.new(response)
+      end
     end
   end
 end
