@@ -46,8 +46,8 @@ module Twitter
       # @param request_method [Symbol]
       # @param path [String]
       # @param options [Hash]
-      def perform_request(request_method, path, options = {})
-        Twitter::REST::Request.new(self, request_method, path, options).perform
+      def perform_request(request_method, path, options = {}, params = nil)
+        Twitter::REST::Request.new(self, request_method, path, options, params).perform
       end
 
       # @param path [String]
@@ -68,8 +68,8 @@ module Twitter
       # @param path [String]
       # @param options [Hash]
       # @param klass [Class]
-      def perform_request_with_object(request_method, path, options, klass)
-        response = perform_request(request_method, path, options)
+      def perform_request_with_object(request_method, path, options, klass, params = nil)
+        response = perform_request(request_method, path, options, params)
         klass.new(response)
       end
 
@@ -102,9 +102,15 @@ module Twitter
       # @param collection_name [Symbol]
       # @param klass [Class]
       def perform_get_with_cursor(path, options, collection_name, klass = nil)
-        merge_default_cursor!(options)
+        limit = options.delete(:limit)
+        if options[:no_default_cursor]
+          options.delete(:no_default_cursor)
+        else
+          merge_default_cursor!(options)
+        end
+
         request = Twitter::REST::Request.new(self, :get, path, options)
-        Twitter::Cursor.new(collection_name.to_sym, klass, request)
+        Twitter::Cursor.new(collection_name.to_sym, klass, request, limit)
       end
 
       # @param request_method [Symbol]
@@ -151,6 +157,17 @@ module Twitter
         end
       end
 
+      # @param request_method [Symbol]
+      # @param path [String]
+      # @param ids [Array]
+      # @return nil
+      def perform_requests(request_method, path, ids)
+        ids.each do |id|
+          perform_request(request_method, path, id: id)
+        end
+        nil
+      end
+
       # @param collection_name [Symbol]
       # @param klass [Class]
       # @param path [String]
@@ -229,7 +246,7 @@ module Twitter
         hash[:screen_name] = screen_names.join(',') unless screen_names.empty?
       end
 
-      def collect_users(users) # rubocop:disable MethodLength
+      def collect_users(users) # rubocop:disable Metrics/MethodLength
         user_ids = []
         screen_names = []
         users.each do |user|
