@@ -7,9 +7,10 @@ module Twitter
     #
     # @param enumerable [Enumerable]
     # @return [Array, Enumerator]
-    def flat_pmap(enumerable)
+    def flat_pmap(enumerable, &block)
       return to_enum(:flat_pmap, enumerable) unless block_given?
-      pmap(enumerable, &Proc.new).flatten(1)
+
+      pmap(enumerable, &block).flatten(1)
     end
 
     # Returns a new array with the results of running block once for every element in enumerable.
@@ -19,6 +20,7 @@ module Twitter
     # @return [Array, Enumerator]
     def pmap(enumerable)
       return to_enum(:pmap, enumerable) unless block_given?
+
       if enumerable.count == 1
         enumerable.collect { |object| yield(object) }
       else
