@@ -212,7 +212,7 @@ describe Twitter::DirectMessage do
       user_mentions_array = [
         {
           screen_name: 'sferik',
-          name: 'Erik Michaels-Ober',
+          name: 'Erik Berlin',
           id_str: '7_505_382',
           indices: [0, 6],
           id: 7_505_382,
