@@ -1,9 +1,8 @@
 require 'helper'
 
 describe Twitter::Geo::Point do
-
   before do
-    @point = Twitter::Geo::Point.new(:coordinates => [-122.399983, 37.788299])
+    @point = Twitter::Geo::Point.new(coordinates: [-122.399983, 37.788299])
   end
 
   describe '#==' do
@@ -13,15 +12,15 @@ describe Twitter::Geo::Point do
       expect(point == other).to be true
     end
     it 'returns true when objects coordinates are the same' do
-      other = Twitter::Geo::Point.new(:coordinates => [-122.399983, 37.788299])
+      other = Twitter::Geo::Point.new(coordinates: [-122.399983, 37.788299])
       expect(@point == other).to be true
     end
     it 'returns false when objects coordinates are different' do
-      other = Twitter::Geo::Point.new(:coordinates => [37.788299, -122.399983])
+      other = Twitter::Geo::Point.new(coordinates: [37.788299, -122.399983])
       expect(@point == other).to be false
     end
     it 'returns false when classes are different' do
-      other = Twitter::Geo.new(:coordinates => [-122.399983, 37.788299])
+      other = Twitter::Geo.new(coordinates: [-122.399983, 37.788299])
       expect(@point == other).to be false
     end
   end
@@ -37,5 +36,4 @@ describe Twitter::Geo::Point do
       expect(@point.longitude).to eq(37.788299)
     end
   end
-
 end
