@@ -295,14 +295,14 @@ describe Twitter::REST::FriendsAndFollowers do
     before do
       stub_get('/1.1/account/verify_credentials.json').with(query: {skip_status: 'true'}).to_return(body: fixture('sferik.json'), headers: {content_type: 'application/json; charset=utf-8'})
       stub_get('/1.1/friends/ids.json').with(query: {user_id: '7505382', cursor: '-1'}).to_return(body: fixture('ids_list2.json'), headers: {content_type: 'application/json; charset=utf-8'})
-      stub_post('/1.1/users/lookup.json').with(body: {screen_name: 'sferik,pengwynn'}).to_return(body: fixture('friendships.json'), headers: {content_type: 'application/json; charset=utf-8'})
+      stub_get('/1.1/users/lookup.json').with(query: {screen_name: 'sferik,pengwynn'}).to_return(body: fixture('friendships.json'), headers: {content_type: 'application/json; charset=utf-8'})
       stub_post('/1.1/friendships/create.json').with(body: {user_id: '7505382'}).to_return(body: fixture('sferik.json'), headers: {content_type: 'application/json; charset=utf-8'})
     end
     it 'requests the correct resource' do
       @client.follow('sferik', 'pengwynn')
       expect(a_get('/1.1/account/verify_credentials.json').with(query: {skip_status: 'true'})).to have_been_made
       expect(a_get('/1.1/friends/ids.json').with(query: {user_id: '7505382', cursor: '-1'})).to have_been_made
-      expect(a_post('/1.1/users/lookup.json').with(body: {screen_name: 'sferik,pengwynn'})).to have_been_made
+      expect(a_get('/1.1/users/lookup.json').with(query: {screen_name: 'sferik,pengwynn'})).to have_been_made
       expect(a_post('/1.1/friendships/create.json').with(body: {user_id: '7505382'})).to have_been_made
     end
   end
@@ -342,15 +342,6 @@ describe Twitter::REST::FriendsAndFollowers do
       expect(a_post('/1.1/friendships/create.json').with(body: {screen_name: 'sferik'})).to have_been_made
     end
   end
-  context 'with a URI string passed' do
-    before do
-      stub_post('/1.1/friendships/create.json').with(body: {screen_name: 'sferik'}).to_return(body: fixture('sferik.json'), headers: {content_type: 'application/json; charset=utf-8'})
-    end
-    it 'requests the correct resource' do
-      @client.follow!('https://twitter.com/sferik')
-      expect(a_post('/1.1/friendships/create.json').with(body: {screen_name: 'sferik'})).to have_been_made
-    end
-  end
   context 'with a forbidden error' do
     before do
       stub_post('/1.1/friendships/create.json').with(body: {screen_name: 'sferik'}).to_return(status: 403, body: fixture('forbidden.json'), headers: {content_type: 'application/json; charset=utf-8'})
@@ -446,15 +437,6 @@ describe Twitter::REST::FriendsAndFollowers do
         expect(a_get('/1.1/friendships/show.json').with(query: {source_screen_name: 'sferik', target_screen_name: 'pengwynn'})).to have_been_made
       end
     end
-    context 'with URI strings passed' do
-      before do
-        stub_get('/1.1/friendships/show.json').with(query: {source_screen_name: 'sferik', target_screen_name: 'pengwynn'}).to_return(body: fixture('following.json'), headers: {content_type: 'application/json; charset=utf-8'})
-      end
-      it 'requests the correct resource' do
-        @client.friendship('https://twitter.com/sferik', 'https://twitter.com/pengwynn')
-        expect(a_get('/1.1/friendships/show.json').with(query: {source_screen_name: 'sferik', target_screen_name: 'pengwynn'})).to have_been_made
-      end
-    end
   end
 
   describe '#friendship?' do
