@@ -422,6 +422,22 @@ describe Twitter::REST::Tweets do
         expect(tweet).to be_a Twitter::Tweet
         expect(tweet.text).to eq('Powerful cartoon by @BillBramhall: http://t.co/IOEbc5QoES')
       end
+      context 'which size is bigger than 5 megabytes' do
+        let(:big_gif) { fixture('pbjt.gif') }
+        before do
+          expect(File).to receive(:size).with(big_gif).and_return(7_000_000)
+        end
+        it 'requests the correct resource' do
+          @client.update_with_media('Powerful cartoon by @BillBramhall: http://t.co/IOEbc5QoES', big_gif)
+          expect(a_request(:post, 'https://upload.twitter.com/1.1/media/upload.json')).to have_been_made.times(3)
+          expect(a_post('/1.1/statuses/update.json')).to have_been_made
+        end
+        it 'returns a Tweet' do
+          tweet = @client.update_with_media('Powerful cartoon by @BillBramhall: http://t.co/IOEbc5QoES', big_gif)
+          expect(tweet).to be_a Twitter::Tweet
+          expect(tweet.text).to eq('Powerful cartoon by @BillBramhall: http://t.co/IOEbc5QoES')
+        end
+      end
     end
     context 'with a jpe image' do
       it 'requests the correct resource' do
@@ -446,10 +462,58 @@ describe Twitter::REST::Tweets do
     end
     context 'with a mp4 video' do
       it 'requests the correct resources' do
+        init_request = {body: fixture('chunk_upload_init.json'), headers: {content_type: 'application/json; charset=utf-8'}}
+        append_request = {body: '', headers: {content_type: 'text/html;charset=utf-8'}}
+        finalize_request = {body: fixture('chunk_upload_finalize_succeeded.json'), headers: {content_type: 'application/json; charset=utf-8'}}
+        stub_request(:post, 'https://upload.twitter.com/1.1/media/upload.json').to_return(init_request, append_request, finalize_request)
         @client.update_with_media('You always have options', fixture('1080p.mp4'))
         expect(a_request(:post, 'https://upload.twitter.com/1.1/media/upload.json')).to have_been_made.times(3)
         expect(a_post('/1.1/statuses/update.json')).to have_been_made
       end
+      context 'when the processing is not finished right after the upload' do
+        context 'when it succeeds' do
+          it 'asks for status until the processing is done' do
+            init_request = {body: fixture('chunk_upload_init.json'), headers: {content_type: 'application/json; charset=utf-8'}}
+            append_request = {body: '', headers: {content_type: 'text/html;charset=utf-8'}}
+            finalize_request = {body: fixture('chunk_upload_finalize_pending.json'), headers: {content_type: 'application/json; charset=utf-8'}}
+            pending_status_request = {body: fixture('chunk_upload_status_pending.json'), headers: {content_type: 'application/json; charset=utf-8'}}
+            completed_status_request = {body: fixture('chunk_upload_status_succeeded.json'), headers: {content_type: 'application/json; charset=utf-8'}}
+            stub_request(:post, 'https://upload.twitter.com/1.1/media/upload.json').to_return(init_request, append_request, finalize_request)
+            stub_request(:get, 'https://upload.twitter.com/1.1/media/upload.json?command=STATUS&media_id=710511363345354753').to_return(pending_status_request, completed_status_request)
+            expect_any_instance_of(Twitter::REST::DirectMessages).to receive(:sleep).with(5).and_return(5)
+            expect_any_instance_of(Twitter::REST::DirectMessages).to receive(:sleep).with(10).and_return(10)
+            @client.update_with_media('You always have options', fixture('1080p.mp4'))
+            expect(a_request(:post, 'https://upload.twitter.com/1.1/media/upload.json')).to have_been_made.times(3)
+            expect(a_request(:get, 'https://upload.twitter.com/1.1/media/upload.json?command=STATUS&media_id=710511363345354753')).to have_been_made.times(2)
+            expect(a_post('/1.1/statuses/update.json')).to have_been_made
+          end
+        end
+        context 'when it fails' do
+          it 'raises an error' do
+            init_request = {body: fixture('chunk_upload_init.json'), headers: {content_type: 'application/json; charset=utf-8'}}
+            append_request = {body: '', headers: {content_type: 'text/html;charset=utf-8'}}
+            finalize_request = {body: fixture('chunk_upload_finalize_pending.json'), headers: {content_type: 'application/json; charset=utf-8'}}
+            failed_status_request = {body: fixture('chunk_upload_status_failed.json'), headers: {content_type: 'application/json; charset=utf-8'}}
+            stub_request(:post, 'https://upload.twitter.com/1.1/media/upload.json').to_return(init_request, append_request, finalize_request)
+            stub_request(:get, 'https://upload.twitter.com/1.1/media/upload.json?command=STATUS&media_id=710511363345354753').to_return(failed_status_request)
+            expect_any_instance_of(Twitter::REST::DirectMessages).to receive(:sleep).with(5).and_return(5)
+            expect { @client.update_with_media('You always have options', fixture('1080p.mp4')) }.to raise_error(Twitter::Error::InvalidMedia)
+            expect(a_request(:post, 'https://upload.twitter.com/1.1/media/upload.json')).to have_been_made.times(3)
+            expect(a_request(:get, 'https://upload.twitter.com/1.1/media/upload.json?command=STATUS&media_id=710511363345354753')).to have_been_made
+          end
+        end
+        context 'when Twitter::Client#timeouts[:upload] is set' do
+          before(:each) { @client.timeouts = {upload: 0.1} }
+          it 'raises an error when the finalize step is too slow' do
+            init_request = {body: fixture('chunk_upload_init.json'), headers: {content_type: 'application/json; charset=utf-8'}}
+            append_request = {body: '', headers: {content_type: 'text/html;charset=utf-8'}}
+            finalize_request = {body: fixture('chunk_upload_finalize_pending.json'), headers: {content_type: 'application/json; charset=utf-8'}}
+            stub_request(:post, 'https://upload.twitter.com/1.1/media/upload.json').to_return(init_request, append_request, finalize_request)
+            expect { @client.update_with_media('You always have options', fixture('1080p.mp4')) }.to raise_error(Twitter::Error::TimeoutError)
+            expect(a_request(:post, 'https://upload.twitter.com/1.1/media/upload.json')).to have_been_made.times(3)
+          end
+        end
+      end
     end
     context 'with a Tempfile' do
       it 'requests the correct resource' do
