@@ -92,6 +92,11 @@ describe Twitter::Tweet do
       expect(tweet.full_text).to be_a String
       expect(tweet.full_text).to eq('BOOSH')
     end
+    it 'returns the text of an extended Tweet' do
+      tweet = Twitter::Tweet.new(id: 28_669_546_014, text: nil, full_text: 'BOOSH')
+      expect(tweet.full_text).to be_a String
+      expect(tweet.full_text).to eq('BOOSH')
+    end
     it 'returns the text of a Tweet without a user' do
       tweet = Twitter::Tweet.new(id: 28_669_546_014, text: 'BOOSH', retweeted_status: {id: 28_561_922_517, text: 'BOOSH'})
       expect(tweet.full_text).to be_a String
@@ -447,7 +452,7 @@ describe Twitter::Tweet do
       user_mentions_array = [
         {
           screen_name: 'sferik',
-          name: 'Erik Michaels-Ober',
+          name: 'Erik Berlin',
           id_str: '7_505_382',
           indices: [0, 6],
           id: 7_505_382,
